Django pickling
===============

Makes django models pickling 2-3 times faster and compact.


Installation and setup
----------------------

    $ pip install django-pickling

Then add ``django_pickling`` to your ``INSTALLED_APPS``.
